@@ -300,7 +300,7 @@ class ArcGISRESTfulBase:
             return utils.ESRIGeomQuery((geom.x, geom.y), self.out_sr).point()
 
         if isinstance(geom, MultiPoint):
-            return utils.ESRIGeomQuery([(g.x, g.y) for g in geom], self.out_sr).multipoint()
+            return utils.ESRIGeomQuery([(g.x, g.y) for g in geom.geoms], self.out_sr).multipoint()
 
         if isinstance(geom, Polygon):
             return utils.ESRIGeomQuery(geom, self.out_sr).polygon()
@@ -325,18 +325,15 @@ class ArcGISRESTfulBase:
     def _retry_failed_requests(self) -> List[Dict[str, Any]]:
         """Retry failed requests."""
         self.retry = True
-        partition_fac = 0.5
+        fac_min = 1.0 / self.max_nrecords
+        n_retry = 4
+        partition_fac = [(0.5 - fac_min) / (n_retry - 1) * i + fac_min for i in range(n_retry)]
         features = []
-        while True:
+        for f in partition_fac[::-1]:
             try:
-                features.append(self._retry(self.return_m, partition_fac))
+                features.append(self._retry(self.return_m, f))
             except ServiceError:
-                partition_fac *= 0.5
-                try:
-                    features.append(self._retry(self.return_m, partition_fac))
-                except ServiceError:
-                    features.append(self._retry(self.return_m, 1.0 / self.max_nrecords))
-                    break
+                continue
 
         logger.info(
             f"Total of {self.n_missing} out of {self.total_n_features} "
@@ -518,6 +515,10 @@ class WFSBase:
     read_method : str, optional
         Method for reading the retrieved data, defaults to ``json``. Valid options are
         ``json``, ``binary``, and ``text``.
+    max_nrecords : int, optional
+        The maximum number of records in a single request to be retrieved from the service,
+        defaults to 1000. If the number of records requested is greater than this value,
+        it will be split into multiple requests.
     """
 
     url: str
@@ -526,6 +527,7 @@ class WFSBase:
     version: str = "2.0.0"
     crs: str = DEF_CRS
     read_method: str = "json"
+    max_nrecords: int = 1000
 
     def __repr__(self) -> str:
         """Print the services properties."""
@@ -586,7 +588,7 @@ class WFSBase:
         payload = {
             "service": "wfs",
             "version": self.version,
-            "outputFormat": self.outformat,
+            "outputFormat": "application/json",
             "request": "GetFeature",
             "typeName": self.layer,
             max_features: 1,
