@@ -7,6 +7,7 @@ from types import SimpleNamespace
 from typing import Any, Dict, List, Optional, Tuple, Union
 
 import async_retriever as ar
+import cytoolz as tlz
 import pyproj
 import shapely.ops as ops
 import yaml
@@ -335,6 +336,13 @@ class WFS(WFSBase):
     crs: str, optional
         The spatial reference system to be used for requesting the data, defaults to
         epsg:4326.
+    read_method : str, optional
+        Method for reading the retrieved data, defaults to ``json``. Valid options are
+        ``json``, ``binary``, and ``text``.
+    max_nrecords : int, optional
+        The maximum number of records in a single request to be retrieved from the service,
+        defaults to 1000. If the number of records requested is greater than this value,
+        it will be split into multiple requests.
     validation : bool, optional
         Validate the input arguments from the WFS service, defaults to True. Set this
         to False if you are sure all the WFS settings such as layer and crs are correct
@@ -348,9 +356,11 @@ class WFS(WFSBase):
         outformat: Optional[str] = None,
         version: str = "2.0.0",
         crs: str = DEF_CRS,
+        read_method: str = "json",
+        max_nrecords: int = 1000,
         validation: bool = True,
     ) -> None:
-        super().__init__(url, layer, outformat, version, crs)
+        super().__init__(url, layer, outformat, version, crs, read_method, max_nrecords)
 
         if validation:
             self.validate_wfs()
@@ -423,7 +433,7 @@ class WFS(WFSBase):
             If the returned value does not have any geometry, it indicates that most probably the
             axis order does not match. You can set this to True in that case.
         predicate : str, optional
-            The geometric prediacte to use for requesting the data, defaults to ``INTERSECTS``.
+            The geometric predicate to use for requesting the data, defaults to ``INTERSECTS``.
             Valid predicates are:
 
             * ``EQUALS``
@@ -474,7 +484,7 @@ class WFS(WFSBase):
         self,
         featurename: str,
         featureids: Union[List[str], str],
-    ) -> Union[str, bytes, Dict[str, Any]]:
+    ) -> List[Union[str, bytes, Dict[str, Any]]]:
         """Get features based on feature IDs.
 
         Parameters
@@ -493,17 +503,23 @@ class WFS(WFSBase):
         if featurename not in valid_features:
             raise InvalidInputValue("featurename", valid_features)
 
-        featureids = featureids if isinstance(featureids, list) else [featureids]
+        if not isinstance(featureids, (str, int, list)):
+            raise InvalidInputType("featureids", "str or list of str")
+
+        featureids = [featureids] if isinstance(featureids, (str, int)) else featureids
 
         if len(featureids) == 0:
             raise InvalidInputType("featureids", "int or str or list")
 
-        fid_list = ", ".join(f"'{fid}'" for fid in featureids)
+        fid_list = (
+            ", ".join(f"'{fid}'" for fid in fids)
+            for fids in tlz.partition_all(self.max_nrecords, set(featureids))
+        )
 
-        if len(featureids) > 200:
-            return self.getfeature_byfilter(f"{featurename} IN ({fid_list})", method="POST")
-
-        return self.getfeature_byfilter(f"{featurename} IN ({fid_list})")
+        return [
+            self.getfeature_byfilter(f"{featurename} IN ({fids})", method="POST")
+            for fids in fid_list
+        ]
 
     def getfeature_byfilter(
         self, cql_filter: str, method: str = "GET"
@@ -546,14 +562,12 @@ class WFS(WFSBase):
         }
 
         if method == "GET":
-            resp = ar.retrieve([self.url], self.read_method, [{"params": payload}])
-        elif method == "POST":
-            headers = {"content-type": "application/x-www-form-urlencoded"}
-            resp = ar.retrieve(
-                [self.url], self.read_method, [{"data": payload, "headers": headers}], "POST"
-            )
+            return ar.retrieve([self.url], self.read_method, [{"params": payload}])[0]
 
-        return resp[0]
+        headers = {"content-type": "application/x-www-form-urlencoded"}
+        return ar.retrieve(
+            [self.url], self.read_method, [{"data": payload, "headers": headers}], "POST"
+        )[0]
 
 
 class ServiceURL:
