@@ -3,7 +3,6 @@ import math
 from dataclasses import dataclass
 from pathlib import Path
 from typing import Any, Dict, List, Mapping, Optional, Tuple, TypeVar, Union
-from unittest.mock import _patch, patch
 
 import defusedxml.ElementTree as etree
 import pyproj
@@ -13,7 +12,7 @@ from requests import Response
 from requests.adapters import HTTPAdapter
 from requests.exceptions import RequestException
 from requests_cache import CachedSession
-from requests_cache.backends.sqlite import DbCache
+from requests_cache.backends.sqlite import SQLiteCache
 from shapely import ops
 from urllib3 import Retry
 
@@ -68,7 +67,7 @@ class RetrySession:
         self.cache_name = (
             Path("cache", "http_cache.sqlite") if cache_name is None else Path(cache_name)
         )
-        backend = DbCache(self.cache_name, fast_save=True, timeout=1)
+        backend = SQLiteCache(self.cache_name, fast_save=True, timeout=1)
         self.session = CachedSession(expire_after=EXPIRE, backend=backend)
 
         retry_args = {
@@ -114,11 +113,6 @@ class RetrySession:
         else:
             return resp
 
-    @staticmethod
-    def onlyipv4() -> _patch:
-        """Disable IPv6 and only use IPv4."""
-        return patch("socket.has_ipv6", False)
-
 
 def traverse_json(
     obj: Union[Dict[str, Any], List[Dict[str, Any]]], path: Union[str, List[str]]
